pub struct Dispatcher { /* private fields */ }Available on crate feature
virt only.Trait Implementations
Sourceimpl Debug for Dispatcher
impl Debug for Dispatcher
Sourceimpl Default for Dispatcher
impl Default for Dispatcher
Sourcefn default() -> Dispatcher
fn default() -> Dispatcher
Returns the “default value” for a type. Read more
Sourceimpl ExtensionDispatch for Dispatcher
impl ExtensionDispatch for Dispatcher
Sourcetype BackendId = BackendIds
type BackendId = BackendIds
The ID type for the custom backends used by this dispatch implementation.
Sourcetype Context = StagingContext
type Context = StagingContext
The context type used by this dispatch.
Sourcetype ExtensionId = ExtensionIds
type ExtensionId = ExtensionIds
The ID type for the extensions supported by this dispatch implementation.
Sourcefn core_request<P: Platform>(
&mut self,
_backend: &Self::BackendId,
ctx: &mut Context<Self::Context>,
request: &Request,
resources: &mut ServiceResources<P>,
) -> Result<Reply, Error>
fn core_request<P: Platform>( &mut self, _backend: &Self::BackendId, ctx: &mut Context<Self::Context>, request: &Request, resources: &mut ServiceResources<P>, ) -> Result<Reply, Error>
Executes a request using a backend or returns
Error::RequestNotAvailable if it is not
supported by the backend.Sourcefn extension_request<P: Platform>(
&mut self,
_backend: &Self::BackendId,
extension: &Self::ExtensionId,
ctx: &mut Context<Self::Context>,
request: &SerdeExtension,
resources: &mut ServiceResources<P>,
) -> Result<SerdeExtension, Error>
fn extension_request<P: Platform>( &mut self, _backend: &Self::BackendId, extension: &Self::ExtensionId, ctx: &mut Context<Self::Context>, request: &SerdeExtension, resources: &mut ServiceResources<P>, ) -> Result<SerdeExtension, Error>
Executes an extension request using a backend or returns
Error::RequestNotAvailable
if it is not supported by the backend.Sourceimpl ExtensionId<ChunkedExtension> for Dispatcher
Available on crate feature chunked only.
impl ExtensionId<ChunkedExtension> for Dispatcher
Available on crate feature
chunked only.Sourceconst ID: ExtensionIds = ExtensionIds::Chunked
const ID: ExtensionIds = ExtensionIds::Chunked
The ID assigned to the
E extension.Sourcetype Id = ExtensionIds
type Id = ExtensionIds
The ID type used by the runner.
Sourceimpl ExtensionId<FsInfoExtension> for Dispatcher
Available on crate feature fs-info only.
impl ExtensionId<FsInfoExtension> for Dispatcher
Available on crate feature
fs-info only.Sourceconst ID: ExtensionIds = ExtensionIds::FsInfo
const ID: ExtensionIds = ExtensionIds::FsInfo
The ID assigned to the
E extension.Sourcetype Id = ExtensionIds
type Id = ExtensionIds
The ID type used by the runner.
Sourceimpl ExtensionId<HkdfExtension> for Dispatcher
Available on crate feature hkdf only.
impl ExtensionId<HkdfExtension> for Dispatcher
Available on crate feature
hkdf only.Sourceconst ID: ExtensionIds = ExtensionIds::Hkdf
const ID: ExtensionIds = ExtensionIds::Hkdf
The ID assigned to the
E extension.Sourcetype Id = ExtensionIds
type Id = ExtensionIds
The ID type used by the runner.
Sourceimpl ExtensionId<HpkeExtension> for Dispatcher
Available on crate feature hpke only.
impl ExtensionId<HpkeExtension> for Dispatcher
Available on crate feature
hpke only.Sourceconst ID: ExtensionIds = ExtensionIds::Hpke
const ID: ExtensionIds = ExtensionIds::Hpke
The ID assigned to the
E extension.Sourcetype Id = ExtensionIds
type Id = ExtensionIds
The ID type used by the runner.
Sourceimpl ExtensionId<ManageExtension> for Dispatcher
Available on crate feature manage only.
impl ExtensionId<ManageExtension> for Dispatcher
Available on crate feature
manage only.Sourceconst ID: ExtensionIds = ExtensionIds::Manage
const ID: ExtensionIds = ExtensionIds::Manage
The ID assigned to the
E extension.Sourcetype Id = ExtensionIds
type Id = ExtensionIds
The ID type used by the runner.
Sourceimpl ExtensionId<WrapKeyToFileExtension> for Dispatcher
Available on crate feature wrap-key-to-file only.
impl ExtensionId<WrapKeyToFileExtension> for Dispatcher
Available on crate feature
wrap-key-to-file only.Sourceconst ID: ExtensionIds = ExtensionIds::WrapKeyToFile
const ID: ExtensionIds = ExtensionIds::WrapKeyToFile
The ID assigned to the
E extension.Sourcetype Id = ExtensionIds
type Id = ExtensionIds
The ID type used by the runner.